package com.gic.store.strategy.impl;

import com.gic.member.config.api.dto.UserOwnerDefaultDTO;
import com.gic.member.config.api.service.CardAscriptionConfigService;
import com.gic.spark.api.service.SparkJobApiService;
import com.gic.store.constant.StoreStatusEnum;
import com.gic.store.service.StoreLogService;
import com.gic.store.service.StoreService;
import com.gic.store.strategy.BulkUpdateStoreStrtegy;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

@Component("1")
public class StoreStatusStrategyImpl implements BulkUpdateStoreStrtegy {

    @Autowired
    private StoreLogService storeLogService;
    @Autowired
    private SparkJobApiService sparkJobApiService;
    @Autowired
    private CardAscriptionConfigService cardAscriptionConfigService;

    @Override
    public int bulkUpdateStore(String storeInfoIds, Integer enterpriseId, String value, StoreService storeService, Integer operatorId, String operatorName) {
        List<Integer> storeInfoIdList = new ArrayList<>();
        List<UserOwnerDefaultDTO> result = this.cardAscriptionConfigService.getDefaultUserOwner(enterpriseId).getResult();
        if ("all".equals(storeInfoIds)) {
            storeInfoIdList = storeService.listAllStoreInfoId(enterpriseId);
        } else {
            storeInfoIdList = new ArrayList<>();
            String[] storeIdArr = storeInfoIds.split(",");
            for (String s : storeIdArr) {
                storeInfoIdList.add(Integer.valueOf(s));
            }
        }
        if(CollectionUtils.isNotEmpty(result) && StoreStatusEnum.INONLINE.getCode() == Integer.valueOf(value)){
            storeInfoIdList = storeInfoIdList.stream().filter(storeInfoId -> {
                for(UserOwnerDefaultDTO dto : result){
                    if(storeInfoId.intValue() == dto.getStoreInfoId().intValue()){
                        return false;
                    }
                }
                return true;
            }).collect(Collectors.toList());
        }
        if(CollectionUtils.isNotEmpty(storeInfoIdList)){
            String storeInfoIdsNew = StringUtils.join(storeInfoIdList, ",");
            int i = storeService.bulkUpdateStoreStatus(storeInfoIdsNew, enterpriseId, value);
            if (i > 0) {
                int valueCode = Integer.parseInt(value);
                storeLogService.saveBulkStoreStatusLog(storeInfoIdList, enterpriseId, operatorId, operatorName, "门店状态变更为【" + StoreStatusEnum.parseCode(valueCode) + "】");
                for (Integer storeInfoId : storeInfoIdList) {
                    // 启用禁用的值和会员组取的不一致 需要转换下
                    sparkJobApiService.updateStoreStatus(enterpriseId, storeInfoId, StoreStatusEnum.ONLINE.getCode() == valueCode ? 0 : 1);

                }
            }
            return i;
        }
        return 0;
    }
}
